==> mule-datasense-4.0.0-rc-sources.jar: org/mule/datasense/impl/phases/typing/AstTyping.java <==
package org.mule.datasense.impl.phases.typing;

import org.mule.datasense.impl.model.ast.AstNode;
import org.mule.datasense.impl.model.ast.AstNotification;
import org.mule.datasense.impl.phases.annotators.AnnotatorsRegistry;
import org.mule.datasense.impl.DataSenseProviderResolver;
import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.phases.scoping.ExpectedAstVisitor;
import org.mule.datasense.impl.phases.scoping.ExpectedAstVisitorContext;
import org.mule.datasense.impl.phases.scoping.IncomingAstVisitor;
import org.mule.datasense.impl.phases.scoping.IncomingAstVisitorContext;
import org.mule.datasense.impl.phases.typing.resolver.TypeResolverRegistry;

public class AstTyping {

  private final TypeResolverRegistry typeResolverRegistry;
  private final AnnotatorsRegistry annotatorsRegistry;

  public AstTyping(AnnotatorsRegistry annotatorsRegistry, TypeResolverRegistry typeResolverRegistry) {
    this.annotatorsRegistry = annotatorsRegistry;
    this.typeResolverRegistry = typeResolverRegistry;
  }

  public void annotate(AstNode astNode, DataSenseProviderResolver dataSenseProviderResolver,
                       AstNotification astNotification) {
    annotate(astNode, dataSenseProviderResolver, astNotification, new AnnotatingMuleAstVisitor(annotatorsRegistry));
  }

  public void annotate(AstNode astNode, DataSenseProviderResolver dataSenseProviderResolver,
                       AstNotification astNotification, AnnotatingMuleAstVisitor annotatingMuleAstVisitor) {
    annotatingMuleAstVisitor.annotate(astNode, dataSenseProviderResolver, astNotification);
  }

  public void resolveTypes(AstNode astNode, EventType eventType, AstNotification astNotification) {
    TypingMuleAstVisitor typingMuleAstVisitor = new TypingMuleAstVisitor(typeResolverRegistry);
    typingMuleAstVisitor.resolveType(astNode, eventType, astNotification);
  }

  public void generateIncoming(AstNode astNode, EventType eventType, AstNotification astNotification) {
    IncomingAstVisitorContext incomingAstVisitorContext = new IncomingAstVisitorContext(typeResolverRegistry, astNotification);
    incomingAstVisitorContext.setIncomingEventType(eventType);
    astNode.accept(new IncomingAstVisitor(), incomingAstVisitorContext);
  }

  public void generateExpected(AstNode astNode, EventType eventType, AstNotification astNotification) {
    ExpectedAstVisitorContext expectedAstVisitorContext = new ExpectedAstVisitorContext(typeResolverRegistry, astNotification);
    astNode.accept(new ExpectedAstVisitor(), expectedAstVisitorContext);
  }

}

==> mule-datasense-4.5.0-20220523-sources.jar: org/mule/datasense/impl/phases/typing/AstTyping.java <==
package org.mule.datasense.impl.phases.typing;

import org.mule.datasense.impl.DataSenseProviderResolver;
import org.mule.datasense.impl.model.ast.AstNode;
import org.mule.datasense.impl.model.ast.AstNotification;
import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.phases.annotators.AnnotatorsRegistry;
import org.mule.datasense.impl.phases.scoping.ExpectedAstVisitor;
import org.mule.datasense.impl.phases.scoping.ExpectedAstVisitorContext;
import org.mule.datasense.impl.phases.scoping.IncomingAstVisitor;
import org.mule.datasense.impl.phases.scoping.IncomingAstVisitorContext;
import org.mule.datasense.impl.phases.typing.resolver.TypeResolverRegistry;
import org.mule.runtime.api.metadata.ExpressionLanguageMetadataService;

public class AstTyping {

  private final TypeResolverRegistry typeResolverRegistry;
  private final AnnotatorsRegistry annotatorsRegistry;

  public AstTyping(AnnotatorsRegistry annotatorsRegistry, TypeResolverRegistry typeResolverRegistry) {
    this.annotatorsRegistry = annotatorsRegistry;
    this.typeResolverRegistry = typeResolverRegistry;
  }

  public void annotate(AstNode astNode, DataSenseProviderResolver dataSenseProviderResolver,
                       AstNotification astNotification) {
    annotate(astNode, dataSenseProviderResolver, astNotification, new AnnotatingMuleAstVisitor(annotatorsRegistry));
  }

  public void annotate(AstNode astNode, DataSenseProviderResolver dataSenseProviderResolver,
                       AstNotification astNotification, AnnotatingMuleAstVisitor annotatingMuleAstVisitor) {
    annotatingMuleAstVisitor.annotate(astNode, dataSenseProviderResolver, astNotification);
  }

  public void resolveTypes(AstNode astNode, EventType eventType, AstNotification astNotification,
                           ExpressionLanguageMetadataService expressionLanguageMetadataService) {
    TypingMuleAstVisitor typingMuleAstVisitor =
        new TypingMuleAstVisitor(typeResolverRegistry, expressionLanguageMetadataService);
    typingMuleAstVisitor.resolveType(astNode, eventType, astNotification);
  }

  public void generateIncoming(AstNode astNode, EventType eventType, AstNotification astNotification,
                               ExpressionLanguageMetadataService expressionLanguageMetadataService) {
    IncomingAstVisitorContext incomingAstVisitorContext =
        new IncomingAstVisitorContext(typeResolverRegistry, astNotification, expressionLanguageMetadataService);
    incomingAstVisitorContext.setIncomingEventType(eventType);
    astNode.accept(new IncomingAstVisitor(), incomingAstVisitorContext);
  }

  public void generateExpected(AstNode astNode, EventType eventType, AstNotification astNotification,
                               ExpressionLanguageMetadataService expressionLanguageMetadataService) {
    ExpectedAstVisitorContext expectedAstVisitorContext =
        new ExpectedAstVisitorContext(typeResolverRegistry, astNotification, expressionLanguageMetadataService);
    astNode.accept(new ExpectedAstVisitor(), expectedAstVisitorContext);
  }

}
